==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/javascript/BundlerOptions.java <==
package io.github.cdklabs.projen.javascript;

/**
 * (experimental) Options for `Bundler`.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.831Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.javascript.BundlerOptions")
@software.amazon.jsii.Jsii.Proxy(BundlerOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface BundlerOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) Install the `bundle` command as a pre-compile phase.
     * <p>
     * Default: true
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getAddToPreCompile() {
        return null;
    }

    /**
     * (experimental) Output directory for all bundles.
     * <p>
     * Default: "assets"
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.String getAssetsDir() {
        return null;
    }

    /**
     * (experimental) The semantic version requirement for `esbuild`.
     * <p>
     * Default: - no specific version (implies latest)
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.String getEsbuildVersion() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link BundlerOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link BundlerOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<BundlerOptions> {
        java.lang.Boolean addToPreCompile;
        java.lang.String assetsDir;
        java.lang.String esbuildVersion;

        /**
         * Sets the value of {@link BundlerOptions#getAddToPreCompile}
         * @param addToPreCompile Install the `bundle` command as a pre-compile phase.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder addToPreCompile(java.lang.Boolean addToPreCompile) {
            this.addToPreCompile = addToPreCompile;
            return this;
        }

        /**
         * Sets the value of {@link BundlerOptions#getAssetsDir}
         * @param assetsDir Output directory for all bundles.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder assetsDir(java.lang.String assetsDir) {
            this.assetsDir = assetsDir;
            return this;
        }

        /**
         * Sets the value of {@link BundlerOptions#getEsbuildVersion}
         * @param esbuildVersion The semantic version requirement for `esbuild`.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder esbuildVersion(java.lang.String esbuildVersion) {
            this.esbuildVersion = esbuildVersion;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link BundlerOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public BundlerOptions build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link BundlerOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements BundlerOptions {
        private final java.lang.Boolean addToPreCompile;
        private final java.lang.String assetsDir;
        private final java.lang.String esbuildVersion;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.addToPreCompile = software.amazon.jsii.Kernel.get(this, "addToPreCompile", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
            this.assetsDir = software.amazon.jsii.Kernel.get(this, "assetsDir", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.esbuildVersion = software.amazon.jsii.Kernel.get(this, "esbuildVersion", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.addToPreCompile = builder.addToPreCompile;
            this.assetsDir = builder.assetsDir;
            this.esbuildVersion = builder.esbuildVersion;
        }

        @Override
        public final java.lang.Boolean getAddToPreCompile() {
            return this.addToPreCompile;
        }

        @Override
        public final java.lang.String getAssetsDir() {
            return this.assetsDir;
        }

        @Override
        public final java.lang.String getEsbuildVersion() {
            return this.esbuildVersion;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getAddToPreCompile() != null) {
                data.set("addToPreCompile", om.valueToTree(this.getAddToPreCompile()));
            }
            if (this.getAssetsDir() != null) {
                data.set("assetsDir", om.valueToTree(this.getAssetsDir()));
            }
            if (this.getEsbuildVersion() != null) {
                data.set("esbuildVersion", om.valueToTree(this.getEsbuildVersion()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.javascript.BundlerOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            BundlerOptions.Jsii$Proxy that = (BundlerOptions.Jsii$Proxy) o;

            if (this.addToPreCompile != null ? !this.addToPreCompile.equals(that.addToPreCompile) : that.addToPreCompile != null) return false;
            if (this.assetsDir != null ? !this.assetsDir.equals(that.assetsDir) : that.assetsDir != null) return false;
            return this.esbuildVersion != null ? this.esbuildVersion.equals(that.esbuildVersion) : that.esbuildVersion == null;
        }

        @Override
        public final int hashCode() {
            int result = this.addToPreCompile != null ? this.addToPreCompile.hashCode() : 0;
            result = 31 * result + (this.assetsDir != null ? this.assetsDir.hashCode() : 0);
            result = 31 * result + (this.esbuildVersion != null ? this.esbuildVersion.hashCode() : 0);
            return result;
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/javascript/BundlerOptions.java <==
package io.github.cdklabs.projen.javascript;

/**
 * (experimental) Options for <code>Bundler</code>.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.496Z")
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.javascript.BundlerOptions")
@software.amazon.jsii.Jsii.Proxy(BundlerOptions.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface BundlerOptions extends software.amazon.jsii.JsiiSerializable {

    /**
     * (experimental) Install the <code>bundle</code> command as a pre-compile phase.
     * <p>
     * Default: true
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.Boolean getAddToPreCompile() {
        return null;
    }

    /**
     * (experimental) Output directory for all bundles.
     * <p>
     * Default: "assets"
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.String getAssetsDir() {
        return null;
    }

    /**
     * (experimental) The semantic version requirement for <code>esbuild</code>.
     * <p>
     * Default: - no specific version (implies latest)
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.lang.String getEsbuildVersion() {
        return null;
    }

    /**
     * (experimental) Map of file extensions (without dot) and loaders to use for this file type.
     * <p>
     * Loaders are appended to the esbuild command by <code>--loader:.extension=loader</code>
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    default @org.jetbrains.annotations.Nullable java.util.Map<java.lang.String, java.lang.String> getLoaders() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link BundlerOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link BundlerOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<BundlerOptions> {
        java.lang.Boolean addToPreCompile;
        java.lang.String assetsDir;
        java.lang.String esbuildVersion;
        java.util.Map<java.lang.String, java.lang.String> loaders;

        /**
         * Sets the value of {@link BundlerOptions#getAddToPreCompile}
         * @param addToPreCompile Install the <code>bundle</code> command as a pre-compile phase.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder addToPreCompile(java.lang.Boolean addToPreCompile) {
            this.addToPreCompile = addToPreCompile;
            return this;
        }

        /**
         * Sets the value of {@link BundlerOptions#getAssetsDir}
         * @param assetsDir Output directory for all bundles.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder assetsDir(java.lang.String assetsDir) {
            this.assetsDir = assetsDir;
            return this;
        }

        /**
         * Sets the value of {@link BundlerOptions#getEsbuildVersion}
         * @param esbuildVersion The semantic version requirement for <code>esbuild</code>.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder esbuildVersion(java.lang.String esbuildVersion) {
            this.esbuildVersion = esbuildVersion;
            return this;
        }

        /**
         * Sets the value of {@link BundlerOptions#getLoaders}
         * @param loaders Map of file extensions (without dot) and loaders to use for this file type.
         *                Loaders are appended to the esbuild command by <code>--loader:.extension=loader</code>
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder loaders(java.util.Map<java.lang.String, java.lang.String> loaders) {
            this.loaders = loaders;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link BundlerOptions}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public BundlerOptions build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link BundlerOptions}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements BundlerOptions {
        private final java.lang.Boolean addToPreCompile;
        private final java.lang.String assetsDir;
        private final java.lang.String esbuildVersion;
        private final java.util.Map<java.lang.String, java.lang.String> loaders;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.addToPreCompile = software.amazon.jsii.Kernel.get(this, "addToPreCompile", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
            this.assetsDir = software.amazon.jsii.Kernel.get(this, "assetsDir", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.esbuildVersion = software.amazon.jsii.Kernel.get(this, "esbuildVersion", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.loaders = software.amazon.jsii.Kernel.get(this, "loaders", software.amazon.jsii.NativeType.mapOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class)));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.addToPreCompile = builder.addToPreCompile;
            this.assetsDir = builder.assetsDir;
            this.esbuildVersion = builder.esbuildVersion;
            this.loaders = builder.loaders;
        }

        @Override
        public final java.lang.Boolean getAddToPreCompile() {
            return this.addToPreCompile;
        }

        @Override
        public final java.lang.String getAssetsDir() {
            return this.assetsDir;
        }

        @Override
        public final java.lang.String getEsbuildVersion() {
            return this.esbuildVersion;
        }

        @Override
        public final java.util.Map<java.lang.String, java.lang.String> getLoaders() {
            return this.loaders;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            if (this.getAddToPreCompile() != null) {
                data.set("addToPreCompile", om.valueToTree(this.getAddToPreCompile()));
            }
            if (this.getAssetsDir() != null) {
                data.set("assetsDir", om.valueToTree(this.getAssetsDir()));
            }
            if (this.getEsbuildVersion() != null) {
                data.set("esbuildVersion", om.valueToTree(this.getEsbuildVersion()));
            }
            if (this.getLoaders() != null) {
                data.set("loaders", om.valueToTree(this.getLoaders()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("projen.javascript.BundlerOptions"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            BundlerOptions.Jsii$Proxy that = (BundlerOptions.Jsii$Proxy) o;

            if (this.addToPreCompile != null ? !this.addToPreCompile.equals(that.addToPreCompile) : that.addToPreCompile != null) return false;
            if (this.assetsDir != null ? !this.assetsDir.equals(that.assetsDir) : that.assetsDir != null) return false;
            if (this.esbuildVersion != null ? !this.esbuildVersion.equals(that.esbuildVersion) : that.esbuildVersion != null) return false;
            return this.loaders != null ? this.loaders.equals(that.loaders) : that.loaders == null;
        }

        @Override
        public final int hashCode() {
            int result = this.addToPreCompile != null ? this.addToPreCompile.hashCode() : 0;
            result = 31 * result + (this.assetsDir != null ? this.assetsDir.hashCode() : 0);
            result = 31 * result + (this.esbuildVersion != null ? this.esbuildVersion.hashCode() : 0);
            result = 31 * result + (this.loaders != null ? this.loaders.hashCode() : 0);
            return result;
        }
    }
}
